@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Gettext PO localization files to YAML files.
+"""
+Convert Gettext PO localization files to YAML files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/yaml2po.html
 for examples and usage instructions.
@@ -34,8 +35,14 @@ class po2yaml:
     TargetUnitClass = yaml.YAMLUnit
     MissingTemplateMessage = "A template YAML file must be provided."
 
-    def __init__(self, input_file, output_file, template_file=None,
-                 include_fuzzy=False, output_threshold=None):
+    def __init__(
+        self,
+        input_file,
+        output_file,
+        template_file=None,
+        include_fuzzy=False,
+        output_threshold=None,
+    ):
         """Initialize the converter."""
         if template_file is None:
             raise ValueError(self.MissingTemplateMessage)
@@ -54,8 +61,7 @@ class po2yaml:
 
     def convert_unit(self, unit):
         """Convert a source format unit to a target format unit."""
-        use_target = (unit.istranslated()
-                      or unit.isfuzzy() and self.include_fuzzy)
+        use_target = unit.istranslated() or (unit.isfuzzy() and self.include_fuzzy)
         target_unit = self.TargetUnitClass(
             source=unit.target if use_target else unit.source,
         )
@@ -64,7 +70,8 @@ class po2yaml:
         return target_unit
 
     def merge_stores(self):
-        """Convert a source file to a target file using a template file.
+        """
+        Convert a source file to a target file using a template file.
 
         Source file is in source format, while target and template files use
         target format.
@@ -88,12 +95,14 @@ class po2yaml:
         return 1
 
 
-def run_converter(inputfile, outputfile, templatefile=None, includefuzzy=False,
-                  outputthreshold=None):
+def run_converter(
+    inputfile, outputfile, templatefile=None, includefuzzy=False, outputthreshold=None
+):
     """Wrapper around converter."""
     # TODO add Ruby personality.
-    return po2yaml(inputfile, outputfile, templatefile, includefuzzy,
-                   outputthreshold).run()
+    return po2yaml(
+        inputfile, outputfile, templatefile, includefuzzy, outputthreshold
+    ).run()
 
 
 formats = (
@@ -105,12 +114,13 @@ formats = (
 
 
 def main(argv=None):
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, description=__doc__
+    )
     parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
