@@ -368,232 +368,650 @@ cldr_plural_categories = [
     "other",
 ]
 
-"""List of plural tags generated from CLDR 41.0.0 using
+"""List of plural tags generated from CLDR 44.0.1 using
 https://github.com/WeblateOrg/language-data
 """
 plural_tags = {
+    "adp": ["other"],
     "af": ["one", "other"],
+    "afr": ["one", "other"],
     "ak": ["one", "other"],
+    "aka": ["one", "other"],
+    "alb": ["one", "other"],
+    "als": ["one", "other"],
     "am": ["one", "other"],
+    "amh": ["one", "other"],
     "an": ["one", "other"],
     "ar": ["zero", "one", "two", "few", "many", "other"],
+    "ara": ["zero", "one", "two", "few", "many", "other"],
+    "arb": ["zero", "one", "two", "few", "many", "other"],
+    "arg": ["one", "other"],
+    "arm": ["one", "other"],
     "ars": ["zero", "one", "two", "few", "many", "other"],
+    "ary": ["zero", "one", "two", "few", "many", "other"],
     "as": ["one", "other"],
     "asa": ["one", "other"],
+    "asm": ["one", "other"],
     "ast": ["one", "other"],
     "az": ["one", "other"],
+    "aze": ["one", "other"],
+    "azj": ["one", "other"],
     "bal": ["one", "other"],
+    "bam": ["other"],
+    "baq": ["one", "other"],
+    "base": ["one", "other"],
+    "bcc": ["one", "other"],
+    "bd": ["one", "other"],
     "be": ["one", "few", "many"],
+    "be@latin": ["one", "few", "many"],
+    "bel": ["one", "few", "many"],
     "bem": ["one", "other"],
+    "ben": ["one", "other"],
     "bez": ["one", "other"],
     "bg": ["one", "other"],
+    "bgr": ["one", "other"],
+    "bh": ["one", "other"],
     "bho": ["one", "other"],
+    "bih": ["one", "other"],
+    "blo": ["zero", "one", "other"],
     "bm": ["other"],
     "bn": ["one", "other"],
     "bo": ["other"],
+    "bod": ["other"],
+    "bos": ["one", "few", "other"],
+    "bp": ["one", "many", "other"],
     "br": ["one", "two", "few", "many", "other"],
+    "braz_por": ["one", "many", "other"],
+    "bre": ["one", "two", "few", "many", "other"],
     "brx": ["one", "other"],
     "bs": ["one", "few", "other"],
-    "ca": ["one", "other"],
+    "bul": ["one", "other"],
+    "bur": ["other"],
+    "by": ["one", "few", "many"],
+    "ca": ["one", "many", "other"],
+    "cat": ["one", "many", "other"],
     "ce": ["one", "other"],
     "ceb": ["one", "other"],
+    "ces": ["one", "few", "other"],
     "cgg": ["one", "other"],
+    "che": ["one", "other"],
+    "chi": ["other"],
+    "chinese": ["other"],
     "chr": ["one", "other"],
+    "chs": ["other"],
+    "cht": ["other"],
     "ckb": ["one", "other"],
+    "cld": ["one", "other"],
+    "cmn": ["other"],
+    "cn": ["other"],
+    "cnr": ["one", "few", "other"],
+    "cor": ["zero", "one", "two", "few", "many", "other"],
     "cs": ["one", "few", "other"],
+    "csy": ["one", "few", "other"],
     "cy": ["zero", "one", "two", "few", "many", "other"],
+    "cym": ["zero", "one", "two", "few", "many", "other"],
+    "cz": ["one", "few", "other"],
+    "cze": ["one", "few", "other"],
     "da": ["one", "other"],
+    "dan": ["one", "other"],
     "de": ["one", "other"],
+    "des": ["one", "other"],
+    "deu": ["one", "other"],
+    "dgo": ["one", "other"],
+    "div": ["one", "other"],
+    "dk": ["one", "other"],
     "doi": ["one", "other"],
+    "drh": ["one", "other"],
+    "drw": ["one", "other"],
     "dsb": ["one", "two", "few", "other"],
+    "dut": ["one", "other"],
+    "dutch_be": ["one", "other"],
     "dv": ["one", "other"],
     "dz": ["other"],
+    "dzo": ["other"],
     "ee": ["one", "other"],
+    "eg": ["zero", "one", "two", "few", "many", "other"],
+    "ekk": ["one", "other"],
     "el": ["one", "other"],
+    "ell": ["one", "other"],
     "en": ["one", "other"],
+    "ena": ["one", "other"],
+    "eng": ["one", "other"],
+    "english_uk": ["one", "other"],
+    "enp": ["one", "other"],
+    "enu": ["one", "other"],
     "eo": ["one", "other"],
+    "epo": ["one", "other"],
     "es": ["one", "many", "other"],
+    "es_eu": ["one", "other"],
+    "esp": ["one", "many", "other"],
+    "est": ["one", "other"],
     "et": ["one", "other"],
     "eu": ["one", "other"],
+    "eus": ["one", "other"],
+    "ewe": ["one", "other"],
     "fa": ["one", "other"],
+    "fao": ["one", "other"],
+    "fas": ["one", "other"],
+    "fat": ["one", "other"],
     "ff": ["one", "other"],
     "fi": ["one", "other"],
     "fil": ["one", "other"],
+    "fin": ["one", "other"],
+    "flemish": ["one", "other"],
     "fo": ["one", "other"],
     "fr": ["one", "many", "other"],
+    "fra": ["one", "many", "other"],
+    "frb": ["one", "many", "other"],
+    "fre": ["one", "many", "other"],
+    "fry": ["one", "other"],
+    "fuc": ["one", "other"],
+    "ful": ["one", "other"],
     "fur": ["one", "other"],
     "fy": ["one", "other"],
     "ga": ["one", "two", "few", "many", "other"],
+    "gae": ["one", "two", "few", "other"],
+    "gaz": ["one", "other"],
     "gd": ["one", "two", "few", "other"],
+    "geo": ["one", "other"],
+    "ger": ["one", "other"],
     "gl": ["one", "other"],
+    "gla": ["one", "two", "few", "other"],
+    "gle": ["one", "two", "few", "many", "other"],
+    "glg": ["one", "other"],
+    "glv": ["one", "two", "few", "other"],
+    "gr": ["one", "other"],
+    "gre": ["one", "other"],
     "gsw": ["one", "other"],
     "gu": ["one", "other"],
+    "guj": ["one", "other"],
     "guw": ["one", "other"],
     "gv": ["one", "two", "few", "other"],
     "ha": ["one", "other"],
+    "hau": ["one", "other"],
     "haw": ["one", "other"],
-    "he": ["one", "two", "many", "other"],
+    "hbs": ["one", "few", "other"],
+    "he": ["one", "two", "other"],
+    "heb": ["one", "two", "other"],
     "hi": ["one", "other"],
+    "hin": ["one", "other"],
     "hnj": ["other"],
     "hr": ["one", "few", "other"],
+    "hrv": ["one", "few", "other"],
     "hsb": ["one", "two", "few", "other"],
     "hu": ["one", "other"],
+    "hun": ["one", "other"],
     "hy": ["one", "other"],
+    "hye": ["one", "other"],
     "ia": ["one", "other"],
+    "ibo": ["other"],
+    "ice": ["one", "other"],
     "id": ["other"],
+    "ido": ["one", "other"],
     "ig": ["other"],
     "ii": ["other"],
+    "iii": ["other"],
+    "ike": ["one", "two", "other"],
+    "iku": ["one", "two", "other"],
     "in": ["other"],
+    "ina": ["one", "other"],
+    "ind": ["other"],
     "io": ["one", "other"],
     "is": ["one", "other"],
+    "isl": ["one", "other"],
     "it": ["one", "many", "other"],
+    "ita": ["one", "many", "other"],
+    "its": ["one", "many", "other"],
     "iu": ["one", "two", "other"],
-    "iw": ["one", "two", "many", "other"],
+    "iw": ["one", "two", "other"],
     "ja": ["other"],
+    "jav": ["other"],
     "jbo": ["other"],
     "jgo": ["one", "other"],
     "ji": ["one", "other"],
     "jmc": ["one", "other"],
+    "jp": ["other"],
+    "jpn": ["other"],
     "jv": ["other"],
     "jw": ["other"],
     "ka": ["one", "other"],
     "kab": ["one", "other"],
     "kaj": ["one", "other"],
+    "kal": ["one", "other"],
+    "kan": ["one", "other"],
+    "kas": ["one", "other"],
+    "kat": ["one", "other"],
+    "kaz": ["one", "other"],
     "kcg": ["one", "other"],
     "kde": ["other"],
     "kea": ["other"],
+    "khk": ["one", "other"],
+    "khm": ["other"],
+    "kir": ["one", "other"],
     "kk": ["one", "other"],
+    "kk@latin": ["one", "other"],
     "kkj": ["one", "other"],
     "kl": ["one", "other"],
     "km": ["other"],
+    "kmr": ["one", "other"],
     "kn": ["one", "other"],
     "ko": ["other"],
+    "kor": ["other"],
     "ks": ["one", "other"],
     "ksb": ["one", "other"],
     "ksh": ["zero", "one", "other"],
     "ku": ["one", "other"],
+    "kur": ["one", "other"],
     "kw": ["zero", "one", "two", "few", "many", "other"],
     "ky": ["one", "other"],
+    "kz": ["one", "other"],
     "lag": ["zero", "one", "other"],
+    "lah": ["one", "other"],
+    "lao": ["other"],
+    "lav": ["zero", "one", "other"],
     "lb": ["one", "other"],
     "lg": ["one", "other"],
+    "lij": ["one", "other"],
+    "lin": ["one", "other"],
+    "lit": ["one", "few", "other"],
+    "lk": ["one", "other"],
     "lkt": ["other"],
     "ln": ["one", "other"],
     "lo": ["other"],
     "lt": ["one", "few", "other"],
+    "ltz": ["one", "other"],
+    "lug": ["one", "other"],
     "lv": ["zero", "one", "other"],
+    "lvs": ["zero", "one", "other"],
+    "mac": ["one", "other"],
+    "mal": ["one", "other"],
+    "mar": ["one", "other"],
     "mas": ["one", "other"],
+    "may": ["other"],
+    "me": ["one", "few", "other"],
     "mg": ["one", "other"],
     "mgo": ["one", "other"],
     "mk": ["one", "other"],
+    "mkd": ["one", "other"],
     "ml": ["one", "other"],
+    "mlg": ["one", "other"],
+    "mlt": ["one", "two", "few", "many", "other"],
     "mn": ["one", "other"],
     "mo": ["one", "few", "other"],
+    "mol": ["one", "few", "other"],
+    "mon": ["one", "other"],
     "mr": ["one", "other"],
     "ms": ["other"],
-    "mt": ["one", "few", "many", "other"],
+    "msa": ["other"],
+    "mspanish": ["one", "many", "other"],
+    "mt": ["one", "two", "few", "many", "other"],
     "my": ["other"],
+    "mya": ["other"],
     "nah": ["one", "other"],
     "naq": ["one", "two", "other"],
     "nb": ["one", "other"],
+    "nbl": ["one", "other"],
     "nd": ["one", "other"],
+    "nde": ["one", "other"],
     "ne": ["one", "other"],
+    "nep": ["one", "other"],
     "nl": ["one", "other"],
+    "nlb": ["one", "other"],
+    "nld": ["one", "other"],
     "nn": ["one", "other"],
     "nnh": ["one", "other"],
+    "nno": ["one", "other"],
     "no": ["one", "other"],
+    "nob": ["one", "other"],
+    "nor": ["one", "other"],
+    "norwegian": ["one", "other"],
+    "np": ["one", "other"],
+    "npi": ["one", "other"],
     "nqo": ["other"],
     "nr": ["one", "other"],
     "nso": ["one", "other"],
     "ny": ["one", "other"],
+    "nya": ["one", "other"],
     "nyn": ["one", "other"],
     "om": ["one", "other"],
     "or": ["one", "other"],
+    "ori": ["one", "other"],
+    "orm": ["one", "other"],
+    "ory": ["one", "other"],
     "os": ["one", "other"],
     "osa": ["other"],
+    "oss": ["one", "other"],
     "pa": ["one", "other"],
+    "pan": ["one", "other"],
     "pap": ["one", "other"],
+    "pbu": ["one", "other"],
     "pcm": ["one", "other"],
+    "per": ["one", "other"],
+    "pes": ["one", "other"],
+    "pk": ["one", "other"],
     "pl": ["one", "few", "many"],
+    "plk": ["one", "few", "many"],
+    "plt": ["one", "other"],
+    "pnb": ["one", "other"],
+    "pol": ["one", "few", "many"],
+    "por": ["one", "many", "other"],
+    "portuguese_br": ["one", "many", "other"],
+    "portuguese_portugal": ["one", "many", "other"],
     "prg": ["zero", "one", "other"],
+    "prs": ["one", "other"],
     "ps": ["one", "other"],
     "pt": ["one", "many", "other"],
     "pt_PT": ["one", "many", "other"],
+    "ptb": ["one", "many", "other"],
+    "ptg": ["one", "many", "other"],
+    "pu": ["one", "other"],
+    "pus": ["one", "other"],
     "rm": ["one", "other"],
     "ro": ["one", "few", "other"],
     "rof": ["one", "other"],
+    "roh": ["one", "other"],
+    "ron": ["one", "few", "other"],
+    "rs": ["one", "few", "other"],
     "ru": ["one", "few", "many"],
+    "rum": ["one", "few", "other"],
+    "rus": ["one", "few", "many"],
     "rwk": ["one", "other"],
+    "sag": ["other"],
     "sah": ["other"],
     "saq": ["one", "other"],
     "sat": ["one", "two", "other"],
     "sc": ["one", "other"],
+    "scc": ["one", "few", "other"],
+    "schinese": ["other"],
     "scn": ["one", "other"],
+    "scr": ["one", "few", "other"],
     "sd": ["one", "other"],
     "sdh": ["one", "other"],
     "se": ["one", "two", "other"],
     "seh": ["one", "other"],
+    "serbo_croatian": ["one", "few", "other"],
     "ses": ["other"],
     "sg": ["other"],
     "sh": ["one", "few", "other"],
     "shi": ["one", "few", "other"],
     "si": ["one", "other"],
+    "sin": ["one", "other"],
     "sk": ["one", "few", "other"],
+    "sky": ["one", "few", "other"],
     "sl": ["one", "two", "few", "other"],
+    "slk": ["one", "few", "other"],
+    "slo": ["one", "few", "other"],
+    "slv": ["one", "two", "few", "other"],
     "sma": ["one", "two", "other"],
+    "sme": ["one", "two", "other"],
     "smi": ["one", "two", "other"],
     "smj": ["one", "two", "other"],
     "smn": ["one", "two", "other"],
     "sms": ["one", "two", "other"],
     "sn": ["one", "other"],
+    "sna": ["one", "other"],
+    "snd": ["one", "other"],
+    "so": ["one", "other"],
+    "som": ["one", "other"],
+    "sot": ["one", "other"],
+    "source": ["one", "other"],
+    "spa": ["one", "many", "other"],
+    "sq": ["one", "other"],
+    "sqi": ["one", "other"],
+    "sr": ["one", "few", "other"],
+    "sr@cyrillic": ["one", "few", "other"],
+    "sr@latin": ["one", "few", "other"],
+    "srb": ["one", "few", "other"],
+    "src": ["one", "other"],
+    "srd": ["one", "other"],
+    "srl": ["one", "few", "other"],
+    "srp": ["one", "few", "other"],
+    "ss": ["one", "other"],
+    "ssw": ["one", "other"],
+    "ssy": ["one", "other"],
+    "st": ["one", "other"],
+    "su": ["other"],
+    "sun": ["other"],
+    "sv": ["one", "other"],
+    "sve": ["one", "other"],
+    "svk": ["one", "few", "other"],
+    "sw": ["one", "other"],
+    "swa": ["one", "other"],
+    "swc": ["one", "other"],
+    "swe": ["one", "other"],
+    "swh": ["one", "other"],
+    "syr": ["one", "other"],
+    "ta": ["one", "other"],
+    "tam": ["one", "other"],
+    "tchinese": ["other"],
+    "te": ["one", "other"],
+    "tel": ["one", "other"],
+    "teo": ["one", "other"],
+    "tgl": ["one", "other"],
+    "th": ["other"],
+    "tha": ["other"],
+    "ti": ["one", "other"],
+    "tib": ["other"],
+    "tig": ["one", "other"],
+    "tir": ["one", "other"],
+    "tk": ["one", "other"],
+    "tl": ["one", "other"],
+    "tn": ["one", "other"],
+    "tnf": ["one", "other"],
+    "to": ["other"],
+    "ton": ["other"],
+    "tpi": ["other"],
+    "tr": ["one", "other"],
+    "trk": ["one", "other"],
+    "ts": ["one", "other"],
+    "tsn": ["one", "other"],
+    "tso": ["one", "other"],
+    "tuk": ["one", "other"],
+    "tur": ["one", "other"],
+    "tw": ["one", "other"],
+    "twi": ["one", "other"],
+    "tzm": ["one", "other"],
+    "ua": ["one", "few", "many"],
+    "ug": ["one", "other"],
+    "uig": ["one", "other"],
+    "uk": ["one", "few", "many"],
+    "ukr": ["one", "few", "many"],
+    "und": ["other"],
+    "ur": ["one", "other"],
+    "urd": ["one", "other"],
+    "us": ["one", "other"],
+    "uz": ["one", "other"],
+    "uz@cyrillic": ["one", "other"],
+    "uz@latin": ["one", "other"],
+    "uz@latn": ["one", "other"],
+    "uzb": ["one", "other"],
+    "uzn": ["one", "other"],
+    "ve": ["one", "other"],
+    "vec": ["one", "many", "other"],
+    "ven": ["one", "other"],
+    "vi": ["other"],
+    "vie": ["other"],
+    "vn": ["other"],
+    "vo": ["one", "other"],
+    "vol": ["one", "other"],
+    "vun": ["one", "other"],
+    "wa": ["one", "other"],
+    "wae": ["one", "other"],
+    "wel": ["zero", "one", "two", "few", "many", "other"],
+    "wln": ["one", "other"],
+    "wo": ["other"],
+    "wol": ["other"],
+    "xbelorussian": ["one", "few", "many"],
+    "xh": ["one", "other"],
+    "xho": ["one", "other"],
+    "xog": ["one", "other"],
+    "ydd": ["one", "other"],
+    "yi": ["one", "other"],
+    "yid": ["one", "other"],
+    "yo": ["other"],
+    "yor": ["other"],
+    "yue": ["other"],
+    "zh": ["other"],
+    "zhcn": ["other"],
+    "zho": ["other"],
+    "zhtw": ["other"],
+    "zsm": ["other"],
+    "zu": ["one", "other"],
+    "zul": ["one", "other"],
+}
+
+# Qt Linguist plural tags, extracted from
+# https://github.com/WeblateOrg/language-data
+qt_plural_tags = {
+    "aa": ["one", "other"],
+    "ab": ["one", "other"],
+    "af": ["one", "other"],
+    "am": ["one", "other"],
+    "ar": ["zero", "one", "two", "few", "many", "other"],
+    "as": ["one", "other"],
+    "ay": ["one", "other"],
+    "az": ["one", "other"],
+    "ba": ["one", "other"],
+    "be": ["one", "few", "many"],
+    "bg": ["one", "other"],
+    "bi": ["other"],
+    "bn": ["one", "other"],
+    "bo": ["other"],
+    "br": ["one", "other"],
+    "bs": ["one", "few", "many"],
+    "ca": ["one", "other"],
+    "co": ["one", "other"],
+    "cs": ["one", "few", "many"],
+    "cy": ["zero", "one", "few", "many", "other"],
+    "da": ["one", "other"],
+    "de": ["one", "other"],
+    "dv": ["one", "two", "other"],
+    "dz": ["other"],
+    "el": ["one", "other"],
+    "en": ["one", "other"],
+    "eo": ["one", "other"],
+    "es": ["one", "other"],
+    "et": ["one", "other"],
+    "eu": ["one", "other"],
+    "fa": ["other"],
+    "fi": ["one", "other"],
+    "fil": ["zero", "one", "other"],
+    "fj": ["other"],
+    "fo": ["one", "other"],
+    "fr": ["one", "other"],
+    "fur": ["one", "other"],
+    "fy": ["one", "other"],
+    "ga": ["one", "two", "other"],
+    "gd": ["one", "two", "few", "other"],
+    "gl": ["one", "other"],
+    "gn": ["other"],
+    "gu": ["one", "other"],
+    "gv": ["one", "two", "other"],
+    "ha": ["one", "other"],
+    "he": ["one", "other"],
+    "hi": ["one", "other"],
+    "hr": ["one", "few", "many"],
+    "hu": ["other"],
+    "hy": ["one", "other"],
+    "ia": ["one", "other"],
+    "id": ["other"],
+    "ik": ["one", "two", "other"],
+    "is": ["one", "other"],
+    "it": ["one", "other"],
+    "iu": ["one", "two", "other"],
+    "ja": ["other"],
+    "jv": ["other"],
+    "ka": ["one", "other"],
+    "kk": ["one", "other"],
+    "kl": ["one", "other"],
+    "km": ["one", "other"],
+    "kn": ["one", "other"],
+    "ko": ["other"],
+    "ks": ["one", "other"],
+    "ku": ["one", "other"],
+    "kw": ["one", "other"],
+    "ky": ["one", "other"],
+    "la": ["one", "other"],
+    "lb": ["one", "other"],
+    "ln": ["one", "other"],
+    "lo": ["one", "other"],
+    "lt": ["one", "few", "many"],
+    "lv": ["one", "other", "zero"],
+    "mg": ["one", "other"],
+    "mi": ["one", "two", "other"],
+    "mk": ["one", "two", "other"],
+    "ml": ["one", "other"],
+    "mn": ["one", "other"],
+    "mr": ["one", "other"],
+    "ms": ["other"],
+    "mt": ["one", "zero", "few", "other"],
+    "my": ["other"],
+    "na": ["other"],
+    "nb_NO": ["one", "other"],
+    "ne": ["one", "other"],
+    "nl": ["one", "other"],
+    "nn": ["one", "other"],
+    "nso": ["one", "other"],
+    "oc": ["one", "other"],
+    "om": ["other"],
+    "or": ["one", "other"],
+    "pa": ["one", "other"],
+    "pl": ["one", "few", "many"],
+    "ps": ["one", "other"],
+    "pt": ["one", "other"],
+    "qu": ["one", "other"],
+    "rm": ["one", "other"],
+    "rn": ["one", "other"],
+    "ro": ["one", "few", "other"],
+    "ru": ["one", "few", "many"],
+    "rw": ["one", "other"],
+    "sa": ["one", "two", "other"],
+    "sd": ["one", "other"],
+    "se": ["one", "two", "other"],
+    "si": ["one", "other"],
+    "sk": ["one", "few", "many"],
+    "sl": ["one", "two", "few", "other"],
+    "sm": ["one", "two", "other"],
+    "sn": ["one", "other"],
     "so": ["one", "other"],
     "sq": ["one", "other"],
-    "sr": ["one", "few", "other"],
+    "sr": ["one", "few", "many"],
     "ss": ["one", "other"],
-    "ssy": ["one", "other"],
     "st": ["one", "other"],
     "su": ["other"],
     "sv": ["one", "other"],
     "sw": ["one", "other"],
-    "syr": ["one", "other"],
     "ta": ["one", "other"],
     "te": ["one", "other"],
-    "teo": ["one", "other"],
+    "tg": ["one", "other"],
     "th": ["other"],
     "ti": ["one", "other"],
-    "tig": ["one", "other"],
     "tk": ["one", "other"],
-    "tl": ["one", "other"],
     "tn": ["one", "other"],
-    "to": ["other"],
-    "tpi": ["other"],
-    "tr": ["one", "other"],
+    "to": ["one", "other"],
+    "tr": ["other"],
     "ts": ["one", "other"],
-    "tzm": ["one", "other"],
+    "tt": ["other"],
     "ug": ["one", "other"],
     "uk": ["one", "few", "many"],
-    "und": ["other"],
     "ur": ["one", "other"],
     "uz": ["one", "other"],
-    "ve": ["one", "other"],
     "vi": ["other"],
     "vo": ["one", "other"],
-    "vun": ["one", "other"],
     "wa": ["one", "other"],
-    "wae": ["one", "other"],
-    "wo": ["other"],
+    "wo": ["one", "other"],
     "xh": ["one", "other"],
-    "xog": ["one", "other"],
     "yi": ["one", "other"],
     "yo": ["other"],
-    "yue": ["other"],
+    "za": ["other"],
     "zh": ["other"],
     "zu": ["one", "other"],
 }
 
 
 def simplercode(code):
-    """This attempts to simplify the given language code by ignoring country
+    """
+    This attempts to simplify the given language code by ignoring country
     codes, for example.
 
     .. seealso::
@@ -608,8 +1026,7 @@ def simplercode(code):
     separator = normalize_code(code).rfind("-")
     if separator >= 0:
         return code[:separator]
-    else:
-        return ""
+    return ""
 
 
 expansion_factors = {
@@ -621,9 +1038,9 @@ expansion_factors = {
 }
 """Source to target string length expansion factors."""
 
-langcode_re = re.compile("^[a-z]{2,3}([_-][A-Z]{2,3}|)(@[a-zA-Z0-9]+|)$")
-langcode_ire = re.compile("^[a-z]{2,3}([_-][a-z]{2,3})?(@[a-z0-9]+)?$", re.IGNORECASE)
-variant_re = re.compile("^[_-][A-Z]{2,3}(@[a-zA-Z0-9]+|)$")
+langcode_re = re.compile(r"^[a-z]{2,3}([_-][A-Z]{2,3}|)(@[a-zA-Z0-9]+|)$")
+langcode_ire = re.compile(r"^[a-z]{2,3}([_-][a-z]{2,3})?(@[a-z0-9]+)?$", re.IGNORECASE)
+variant_re = re.compile(r"^[_-][A-Z]{2,3}(@[a-zA-Z0-9]+|)$")
 
 
 dialect_name_re = re.compile(r"(.+)\s\(([^)\d]{,25})\)$")
@@ -632,7 +1049,8 @@ dialect_name_re = re.compile(r"(.+)\s\(([^)\d]{,25})\)$")
 
 
 def normalize(string, normal_form="NFC"):
-    """Return a unicode string in its normalized form
+    """
+    Return a unicode string in its normalized form.
 
     :param string: The string to be normalized
     :param normal_form: NFC (default), NFD, NFKC, NFKD
@@ -653,12 +1071,13 @@ __normalised_languages = {normalize_code(key) for key in languages}
 
 
 def simplify_to_common(language_code):
-    """Simplify language code to the most commonly used form for the language,
+    """
+    Simplify language code to the most commonly used form for the language,
     stripping country information for languages that tend not to be localized
-    differently for different countries
+    differently for different countries.
     """
     simpler = simplercode(language_code)
-    if simpler == "":
+    if not simpler:
         return language_code
 
     if normalize_code(language_code) in __normalised_languages:
