@@ -16,13 +16,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Spanish language.
+"""
+This module represents the Spanish language.
 
 .. note:: As it only has special case code for initial inverted punctuation,
    it could also be used for Asturian, Galician, or Catalan.
 """
 
-
 from translate.lang import common
 
 
@@ -35,11 +35,8 @@ class es(common.Common):
         text = super().punctranslate(text)
         # If the first sentence ends with ? or !, prepend inverted ¿ or ¡
         firstmatch = cls.sentencere.match(text)
-        if firstmatch is None:
-            # only one sentence (if any) - use entire string
-            first = text
-        else:
-            first = firstmatch.group()
+        # only one sentence (if any) - use entire string
+        first = text if firstmatch is None else firstmatch.group()
         # remove trailing whitespace
         first = first.strip()
         # protect against incorrectly handling an empty string
