@@ -16,11 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Kannada language.
-
-.. seealso:: http://en.wikipedia.org/wiki/Kannada_language
 """
+This module represents the Kannada language.
 
+.. seealso:: :wp:`Kannada_language`
+"""
 
 from translate.lang import common
 
@@ -29,5 +29,5 @@ class kn(common.Common):
     """This class represents Kannada."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
