@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Class to perform translation memory matching from a store of translation
+"""
+Class to perform translation memory matching from a store of translation
 units.
 """
 
@@ -45,7 +46,8 @@ def _sort_matches(matches, match_info):
 
 
 class matcher:
-    """A class that will do matching and store configuration for the matching
+    """
+    A class that will do matching and store configuration for the matching
     process.
     """
 
@@ -60,10 +62,11 @@ class matcher:
         comparer=None,
         usefuzzy=False,
     ):
-        """max_candidates is the maximum number of candidates that should be
+        """
+        max_candidates is the maximum number of candidates that should be
         assembled, min_similarity is the minimum similarity that must be
         attained to be included in the result, comparer is an optional Comparer
-        with similarity() function
+        with similarity() function.
         """
         if comparer is None:
             comparer = lshtein.LevenshteinComparer(max_length)
@@ -74,7 +77,7 @@ class matcher:
         self.addpercentage = True
 
     def usable(self, unit):
-        """Returns whether this translation unit is usable for TM"""
+        """Returns whether this translation unit is usable for TM."""
         # TODO: We might want to consider more attributes, such as approved, reviewed, etc.
         source = unit.source
         target = unit.target
@@ -83,13 +86,13 @@ class matcher:
                 return False
             if source in self.existingunits and self.existingunits[source] == target:
                 return False
-            else:
-                self.existingunits[source] = target
-                return True
+            self.existingunits[source] = target
+            return True
         return False
 
     def inittm(self, stores, reverse=False):
-        """Initialises the memory for later use. We use simple base units for
+        """
+        Initialises the memory for later use. We use simple base units for
         speedup.
         """
         # reverse is deprectated - just use self.sort_reverse
@@ -103,7 +106,8 @@ class matcher:
         self.candidates.units.sort(key=sourcelen, reverse=self.sort_reverse)
 
     def extendtm(self, units, store=None, sort=True):
-        """Extends the memory with extra unit(s).
+        """
+        Extends the memory with extra unit(s).
 
         :param units: The units to add to the TM.
         :param store: Optional store from where some metadata can be retrieved
@@ -138,28 +142,32 @@ class matcher:
             self.candidates.units.sort(key=sourcelen, reverse=self.sort_reverse)
 
     def setparameters(self, max_candidates=10, min_similarity=75, max_length=70):
-        """Sets the parameters without reinitialising the tm. If a parameter is
-        not specified, it is set to the default, not ignored
+        """
+        Sets the parameters without reinitialising the tm. If a parameter is
+        not specified, it is set to the default, not ignored.
         """
         self.MAX_CANDIDATES = max_candidates
         self.MIN_SIMILARITY = min_similarity
         self.MAX_LENGTH = max_length
 
     def getstoplength(self, min_similarity, text):
-        """Calculates a length beyond which we are not interested.  The extra
+        """
+        Calculates a length beyond which we are not interested.  The extra
         fat is because we don't use plain character distance only.
         """
         return min(len(text) / (min_similarity / 100.0), self.MAX_LENGTH)
 
     @staticmethod
     def getstartlength(min_similarity, text):
-        """Calculates the minimum length we are interested in.  The extra fat
+        """
+        Calculates the minimum length we are interested in.  The extra fat
         is because we don't use plain character distance only.
         """
         return max(len(text) * (min_similarity / 100.0), 1)
 
     def matches(self, text):
-        """Returns a list of possible matches for given source text.
+        """
+        Returns a list of possible matches for given source text.
 
         :type text: String
         :param text: The text that will be search for in the translation memory
@@ -217,7 +225,8 @@ class matcher:
         return self.buildunits(bestcandidates)
 
     def buildunits(self, candidates):
-        """Builds a list of units conforming to base API, with the score
+        """
+        Builds a list of units conforming to base API, with the score
         in the comment.
         """
         units = []
@@ -247,8 +256,8 @@ class matcher:
 ignorepatterns = [
     (r"y\s*$", "ie"),  # category/categories, identify/identifies, apply/applied
     (r"[\s-]+", ""),  # down time / downtime, pre-order / preorder
-    ("-", " "),  # pre-order / pre order
-    (" ", "-"),  # pre order / pre-order
+    (r"-", " "),  # pre-order / pre order
+    (r" ", "-"),  # pre order / pre-order
 ]
 ignorepatterns_re = [(re.compile(a), b) for (a, b) in ignorepatterns]
 
@@ -276,7 +285,7 @@ class terminologymatcher(matcher):
         self.match_info = {}
 
     def inittm(self, store):
-        """Normal initialisation, but convert all source strings to lower case"""
+        """Normal initialisation, but convert all source strings to lower case."""
         super().inittm(store)
         extras = []
         for unit in self.candidates.units:
@@ -315,7 +324,8 @@ class terminologymatcher(matcher):
         return l <= self.MAX_LENGTH and l >= self.getstartlength(None, None)
 
     def matches(self, text):
-        """Normal matching after converting text to lower case. Then replace
+        """
+        Normal matching after converting text to lower case. Then replace
         with the original unit to retain comments, etc.
         """
         text_l = len(text)
@@ -386,7 +396,7 @@ class terminologymatcher(matcher):
 
 # utility functions used by virtaal and tmserver to convert matching units in easily marshallable dictionaries
 def unit2dict(unit):
-    """converts a pounit to a simple dict structure for use over the web"""
+    """Converts a pounit to a simple dict structure for use over the web."""
     return {
         "source": unit.source,
         "target": unit.target,
@@ -397,6 +407,7 @@ def unit2dict(unit):
 
 def _parse_quality(comment):
     """Extracts match quality from po comments."""
-    quality = re.search("([0-9]+)%", comment)
+    quality = re.search(r"([0-9]+)%", comment)
     if quality:
         return quality.group(1)
+    return None
