@@ -17,7 +17,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-"""module for parsing html files for translation"""
+"""module for parsing html files for translation."""
 
 import html.parser
 import re
@@ -32,7 +32,7 @@ html.parser.piclose = re.compile(r"\?>")
 
 
 class htmlunit(base.TranslationUnit):
-    """A unit of translatable/localisable HTML content"""
+    """A unit of translatable/localisable HTML content."""
 
     def __init__(self, source=None):
         super().__init__(source)
@@ -66,6 +66,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         "h4",
         "h5",
         "h6",
+        "label",
         "li",
         "main",
         "nav",
@@ -126,7 +127,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
     ENCODING_RE = re.compile(
         rb"""<meta.*
-                                content.*=.*?charset.*?=\s*?
+                                content.*=.*?charset=\s*?
                                 ([^\s]*)
                                 \s*?["']\s*?>
                              """,
@@ -161,7 +162,8 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         return string
 
     def guess_encoding(self, htmlsrc):
-        """Returns the encoding of the html text.
+        """
+        Returns the encoding of the html text.
 
         We look for 'charset=' within a meta tag to do this.
         """
@@ -251,7 +253,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         # scan the start and end tags captured between translatable content;
         # extend the captured interval to include the matching tags
         for pos in range(start + 1, end - 1):
-            if self.tu_content[pos]["type"] in ("starttag", "endtag") and pos in tagmap:
+            if self.tu_content[pos]["type"] in {"starttag", "endtag"} and pos in tagmap:
                 match = tagmap[pos]
                 start = min(start, match)
                 end = max(end, match + 1)
@@ -328,6 +330,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         name = attrs_dict["name"].lower() if "name" in attrs_dict else None
         if name in self.TRANSLATABLE_METADATA and "content" in attrs_dict:
             return self.create_attribute_tu("content", attrs_dict["content"])
+        return None
 
     @staticmethod
     def translatable_attribute_matches_tag(attrname, tag):
@@ -348,6 +351,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
                     self.getpos()[1] + 1,
                 ),
             }
+        return None
 
     def emit_attribute_translation_units(self, markup):
         if "attribute_tus" in markup:
@@ -412,18 +416,16 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         try:
             popped = self.tag_path.pop()
         except IndexError:
-            raise ParseError(
-                "Mismatched tags: no more tags: line %s" % self.getpos()[0]
-            )
+            raise ParseError(f"Mismatched tags: no more tags: line {self.getpos()[0]}")
         if popped != tag and popped in self.EMPTY_HTML_ELEMENTS:
             popped = self.tag_path.pop()
         if popped != tag:
             raise ParseError(
                 "Mismatched closing tag: "
-                "expected '%s' got '%s' at line %s" % (popped, tag, self.getpos()[0])
+                f"expected '{popped}' got '{tag}' at line {self.getpos()[0]}"
             )
 
-        self.append_markup({"type": "endtag", "html_content": "</%s>" % tag})
+        self.append_markup({"type": "endtag", "html_content": f"</{tag}>"})
 
         if tag in self.TRANSLATABLE_ELEMENTS:
             self.end_translation_unit()
@@ -458,37 +460,37 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         self.append_markup({"type": "data", "html_content": data})
 
     def handle_charref(self, name):
-        """Handle entries in the form &#NNNN; e.g. &#8417;"""
+        """Handle entries in the form &#NNNN; e.g. &#8417;."""
         if name.lower().startswith("x"):
             self.handle_data(chr(int(name[1:], 16)))
         else:
             self.handle_data(chr(int(name)))
 
     def handle_entityref(self, name):
-        """Handle named entities of the form &aaaa; e.g. &rsquo;"""
+        """Handle named entities of the form &aaaa; e.g. &rsquo;."""
         converted = html5.get(name + ";")
-        if name in ["gt", "lt", "amp"] or not converted:
-            self.handle_data("&%s;" % name)
+        if name in {"gt", "lt", "amp"} or not converted:
+            self.handle_data(f"&{name};")
         else:
             self.handle_data(converted)
 
     def handle_comment(self, data):
         self.auto_close_empty_element()
         self.append_markup(
-            {"type": "comment", "html_content": "<!--%s-->" % data, "note": data}
+            {"type": "comment", "html_content": f"<!--{data}-->", "note": data}
         )
 
     def handle_decl(self, decl):
         self.auto_close_empty_element()
-        self.append_markup({"type": "decl", "html_content": "<!%s>" % decl})
+        self.append_markup({"type": "decl", "html_content": f"<!{decl}>"})
 
     def handle_pi(self, data):
         self.auto_close_empty_element()
-        self.append_markup({"type": "pi", "html_content": "<?%s?>" % data})
+        self.append_markup({"type": "pi", "html_content": f"<?{data}?>"})
 
     def unknown_decl(self, data):
         self.auto_close_empty_element()
-        self.append_markup({"type": "cdecl", "html_content": "<![%s]>" % data})
+        self.append_markup({"type": "cdecl", "html_content": f"<![{data}]>"})
 
 
 class POHTMLParser(htmlfile):
