@@ -23,15 +23,15 @@ from translate.storage.placeables.strelem import StringElem
 
 __all__ = (
     "Bpt",
-    "Ept",
-    "X",
     "Bx",
+    "Ept",
     "Ex",
     "G",
     "It",
-    "Sub",
     "Ph",
+    "Sub",
     "UnknownXML",
+    "X",
     "parsers",
     "to_xliff_placeables",
 )
@@ -74,7 +74,8 @@ class Sub(base.Sub):
 
 
 class UnknownXML(StringElem):
-    """Placeable for unrecognized or umimplemented XML nodes. It's main purpose
+    """
+    Placeable for unrecognized or umimplemented XML nodes. It's main purpose
     is to preserve all associated XML data.
     """
 
@@ -92,7 +93,8 @@ class UnknownXML(StringElem):
 
     # SPECIAL METHODS #
     def __repr__(self):
-        """String representation of the sub-tree with the current node as the
+        """
+        String representation of the sub-tree with the current node as the
         root.
 
         Copied from :meth:`StringElem.__repr__`, but includes
@@ -107,15 +109,16 @@ class UnknownXML(StringElem):
         return "<%(class)s{%(tag)s}(%(id)s%(rid)s%(xid)s[%(subs)s])>" % {
             "class": self.__class__.__name__,
             "tag": tag,
-            "id": self.id is not None and 'id="%s" ' % (self.id) or "",
-            "rid": self.rid is not None and 'rid="%s" ' % (self.rid) or "",
-            "xid": self.xid is not None and 'xid="%s" ' % (self.xid) or "",
+            "id": (self.id is not None and f'id="{self.id}" ') or "",
+            "rid": (self.rid is not None and f'rid="{self.rid}" ') or "",
+            "xid": (self.xid is not None and f'xid="{self.xid}" ') or "",
             "subs": elemstr,
         }
 
     # METHODS #
     def copy(self):
-        """Returns a copy of the sub-tree.  This should be overridden in
+        """
+        Returns a copy of the sub-tree.  This should be overridden in
         sub-classes with more data.
 
         .. note:: ``self.renderer`` is **not** copied.
