@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-r"""Classes that hold units of .properties, and similar, files that are used in
+r"""
+Classes that hold units of .properties, and similar, files that are used in
 translating Java, Mozilla, MacOS and other software.
 
 The :class:`propfile` class is a monolingual class with :class:`propunit`
@@ -126,16 +127,25 @@ Name and Value pairs:
 
 """
 
+from __future__ import annotations
+
 import re
 from codecs import iterencode
 from copy import deepcopy
-from typing import List
 
 from lxml import etree
 
 from translate.lang import data
-from translate.misc import quote
 from translate.misc.multistring import multistring
+from translate.misc.quote import (
+    java_utf8_properties_encode,
+    javapropertiesencode,
+    mozillaescapemarginspaces,
+    propertiesdecode,
+    rstripeol,
+    xwiki_properties_decode,
+    xwiki_properties_encode,
+)
 from translate.storage import base
 
 labelsuffixes = (".label", ".title")
@@ -152,8 +162,9 @@ ending in :attr:`.labelsuffixes` into accelerator notation"""
 eol = "\n"
 
 
-def is_line_continuation(line):
-    """Determine whether *line* has a line continuation marker.
+def is_line_continuation(line: str) -> bool:
+    r"""
+    Determine whether *line* has a line continuation marker.
 
     .properties files can be terminated with a backslash (\\) indicating
     that the 'value' continues on the next line.  Continuation is only
@@ -177,8 +188,9 @@ def is_line_continuation(line):
     return (count % 2) == 1  # Odd is a line continuation, even is not
 
 
-def is_comment_one_line(line):
-    """Determine whether a *line* is a one-line comment.
+def get_comment_one_line(line):
+    """
+    Determine whether a *line* is a one-line comment.
 
     :param line: A properties line
     :type line: unicode
@@ -189,14 +201,15 @@ def is_comment_one_line(line):
     line_starters = ("#", "!", "//", ";")
     for starter in line_starters:
         if stripped.startswith(starter):
-            return True
+            return stripped[len(starter) :].strip()
     if stripped.startswith("/*") and stripped.endswith("*/"):
-        return True
-    return False
+        return stripped[2:-2].strip()
+    return None
 
 
-def is_comment_start(line):
-    """Determine whether a *line* starts a new multi-line comment.
+def get_comment_start(line: str) -> str | None:
+    """
+    Determine whether a *line* starts a new multi-line comment.
 
     :param line: A properties line
     :type line: unicode
@@ -204,11 +217,14 @@ def is_comment_start(line):
     :rtype: bool
     """
     stripped = line.strip()
-    return stripped.startswith("/*") and not stripped.endswith("*/")
+    if stripped.startswith("/*") and not stripped.endswith("*/"):
+        return line[2:].strip()
+    return None
 
 
-def is_comment_end(line):
-    """Determine whether a *line* ends a new multi-line comment.
+def get_comment_end(line: str) -> str | None:
+    """
+    Determine whether a *line* ends a new multi-line comment.
 
     :param line: A properties line
     :type line: unicode
@@ -216,11 +232,14 @@ def is_comment_end(line):
     :rtype: bool
     """
     stripped = line.strip()
-    return not stripped.startswith("/*") and stripped.endswith("*/")
+    if not stripped.startswith("/*") and stripped.endswith("*/"):
+        return line[:-2].strip()
+    return None
 
 
-def _key_strip(key):
-    """Cleanup whitespace found around a key
+def _key_strip(key: str) -> str:
+    """
+    Cleanup whitespace found around a key.
 
     :param key: A properties key
     :type key: str
@@ -234,11 +253,11 @@ def _key_strip(key):
     return newkey.lstrip()
 
 
-dialects = {}
+dialects: dict[str, type[Dialect]] = {}
 default_dialect = "java"
 
 
-def register_dialect(dialect):
+def register_dialect(dialect: type[Dialect]) -> type[Dialect]:
     """Decorator that registers the dialect."""
     dialects[dialect.name] = dialect
     return dialect
@@ -251,31 +270,32 @@ def get_dialect(dialect=default_dialect):
 class Dialect:
     """Settings for the various behaviours in key=value files."""
 
-    name = None
-    default_encoding = "iso-8859-1"
-    delimiters: List[str] = []
-    pair_terminator = ""
-    key_wrap_char = ""
-    value_wrap_char = ""
-    drop_comments = []
-    has_plurals = False
+    name: str
+    default_encoding: str = "iso-8859-1"
+    delimiters: list[str] = []
+    pair_terminator: str = ""
+    key_wrap_char: str = ""
+    value_wrap_char: str = ""
+    drop_comments: list[str] = []
+    has_plurals: bool = False
 
     @staticmethod
-    def encode(string, encoding=None):
-        """Encode the string"""
+    def encode(string: str, encoding: str | None = None) -> str:
+        """Encode the string."""
         # FIXME: dialects are a bad idea, not possible for subclasses
         # to override key methods
-        if encoding not in ("utf-8", "utf-16"):
-            return quote.javapropertiesencode(string or "")
-        return quote.java_utf8_properties_encode(string or "")
+        if encoding not in {"utf-8", "utf-16"}:
+            return javapropertiesencode(string or "")
+        return java_utf8_properties_encode(string or "")
 
     @staticmethod
-    def decode(string):
-        return quote.propertiesdecode(string)
+    def decode(string: str) -> str:
+        return propertiesdecode(string)
 
     @classmethod
-    def find_delimiter(cls, line):
-        """Find the type and position of the delimiter in a property line.
+    def find_delimiter(cls, line: str) -> tuple[str | None, int]:
+        """
+        Find the type and position of the delimiter in a property line.
 
         Property files can be delimited by "=", ":" or whitespace (space for now).
         We find the position of each delimiter, then find the one that appears
@@ -294,7 +314,7 @@ class Dialect:
         delimiters = delimiter_dict
         # Figure out starting position
         start_pos = len(line) - len(line.lstrip())  # Skip initial whitespace
-        if cls.key_wrap_char != "" and line[start_pos] == cls.key_wrap_char:
+        if cls.key_wrap_char and line[start_pos] == cls.key_wrap_char:
             # Skip the key if it is delimited by some char
             start_pos += 1
             while line[start_pos] != cls.key_wrap_char or line[start_pos - 1] == "\\":
@@ -332,31 +352,35 @@ class Dialect:
         return (mindelimiter, minpos)
 
     @staticmethod
-    def key_strip(key):
-        """Strip unneeded characters from the key"""
+    def key_strip(key: str) -> str:
+        """Strip unneeded characters from the key."""
         return _key_strip(key)
 
     @staticmethod
-    def value_strip(value):
-        """Strip unneeded characters from the value"""
+    def value_strip(value: str) -> str:
+        """Strip unneeded characters from the value."""
         return value.lstrip()
 
     @staticmethod
-    def is_line_continuation(line):
+    def is_line_continuation(line: str) -> bool:
         return is_line_continuation(line)
 
     @staticmethod
-    def strip_line_continuation(value):
+    def strip_line_continuation(value: str) -> str:
         return value[:-1]
 
     @staticmethod
-    def get_key_cldr_name(key):
+    def get_key_cldr_name(key: str) -> tuple[str, str]:
         return (key, "other")
 
     @staticmethod
-    def get_cldr_names_order():
+    def get_cldr_names_order() -> list[str]:
         return ["other"]
 
+    @staticmethod
+    def get_expand_output_target_mapping(names: list[str]) -> list[str]:
+        return names
+
 
 @register_dialect
 class DialectJava(Dialect):
@@ -373,7 +397,7 @@ class DialectJavaUtf8(DialectJava):
 
     @staticmethod
     def encode(string, encoding=None):
-        return quote.java_utf8_properties_encode(string or "")
+        return java_utf8_properties_encode(string or "")
 
 
 @register_dialect
@@ -384,7 +408,7 @@ class DialectJavaUtf16(DialectJava):
 
     @staticmethod
     def encode(string, encoding=None):
-        return quote.java_utf8_properties_encode(string or "")
+        return java_utf8_properties_encode(string or "")
 
 
 @register_dialect
@@ -402,11 +426,11 @@ class DialectXWiki(DialectJava):
 
     @staticmethod
     def encode(string, encoding=None):
-        return quote.xwiki_properties_encode(string or "", encoding)
+        return xwiki_properties_encode(string or "", encoding)
 
     @staticmethod
     def decode(string):
-        return quote.xwiki_properties_decode(string)
+        return xwiki_properties_decode(string)
 
 
 @register_dialect
@@ -422,10 +446,9 @@ class DialectMozilla(DialectJavaUtf8):
 
     @staticmethod
     def encode(string, encoding=None):
-        """Encode the string"""
-        string = quote.java_utf8_properties_encode(string or "")
-        string = quote.mozillaescapemarginspaces(string or "")
-        return string
+        """Encode the string."""
+        string = java_utf8_properties_encode(string or "")
+        return mozillaescapemarginspaces(string or "")
 
 
 @register_dialect
@@ -469,7 +492,7 @@ class DialectGwt(DialectJavaUtf8):
 
     @classmethod
     def get_cldr_names_order(cls):
-        return [y for x, y in cls.gwt_plural_categories]
+        return [y for _x, y in cls.gwt_plural_categories]
 
     @classmethod
     def get_key(cls, key, variant):
@@ -477,15 +500,15 @@ class DialectGwt(DialectJavaUtf8):
 
         # Some sanity checks
         if not variant:
-            raise Exception(f'Key "{key}" variant "{variant}" is invalid')
+            raise ValueError(f'Key "{key}" variant "{variant}" is invalid')
         return f"{key}[{variant}]"
 
     @classmethod
     def encode(cls, string, encoding=None):
-        if encoding not in ("utf-8", "utf-16"):
-            result = quote.javapropertiesencode(string or "")
+        if encoding not in {"utf-8", "utf-16"}:
+            result = javapropertiesencode(string or "")
         else:
-            result = quote.java_utf8_properties_encode(string or "")
+            result = java_utf8_properties_encode(string or "")
         return result.replace("'", "''")
 
     @classmethod
@@ -493,6 +516,12 @@ class DialectGwt(DialectJavaUtf8):
         result = super().decode(string)
         return result.replace("''", "'")
 
+    @staticmethod
+    def get_expand_output_target_mapping(names: list[str]) -> list[str]:
+        if "other" not in names:
+            return ["other", *names]
+        return names
+
 
 @register_dialect
 class DialectSkype(Dialect):
@@ -502,7 +531,7 @@ class DialectSkype(Dialect):
 
     @staticmethod
     def encode(string, encoding=None):
-        return quote.java_utf8_properties_encode(string or "")
+        return java_utf8_properties_encode(string or "")
 
 
 @register_dialect
@@ -516,10 +545,17 @@ class DialectStrings(Dialect):
     out_ending = ";"
     out_delimiter_wrappers = " "
     drop_comments = ["/* No comment provided by engineer. */"]
+    encode_trans = str.maketrans(
+        {
+            "\\": "\\\\",
+            "\n": r"\n",
+            "\t": r"\t",
+        }
+    )
 
     @staticmethod
     def key_strip(key):
-        """Strip unneeded characters from the key"""
+        """Strip unneeded characters from the key."""
         newkey = key.rstrip().rstrip('"')
         # If string now ends in \ we put back the char that was escaped
         if newkey[-1:] == "\\":
@@ -529,7 +565,7 @@ class DialectStrings(Dialect):
 
     @staticmethod
     def value_strip(value):
-        """Strip unneeded characters from the value"""
+        """Strip unneeded characters from the value."""
         newvalue = value.rstrip().rstrip(";").rstrip('"')
         # If string now ends in \ we put back the char that was escaped
         if newvalue[-1:] == "\\":
@@ -537,16 +573,14 @@ class DialectStrings(Dialect):
         ret = newvalue.lstrip().lstrip('"')
         return ret.replace('\\"', '"')
 
-    @staticmethod
-    def encode(string, encoding=None):
-        return string.replace("\\", "\\\\").replace("\n", r"\n").replace("\t", r"\t")
+    @classmethod
+    def encode(cls, string, encoding=None):  # noqa: ARG003
+        return string.translate(cls.encode_trans)
 
     @staticmethod
     def is_line_continuation(line):
         l = line.rstrip()
-        if l and l[-1] == ";":
-            return False
-        return True
+        return not l or l[-1] != ";"
 
     @staticmethod
     def strip_line_continuation(value):
@@ -624,11 +658,12 @@ class proppluralunit(base.TranslationUnit):
 
     def _get_ordered_units(self):
         # Used for str (GWT order)
-        mapping = self._get_target_mapping()
-        names = []
-        for name in self.personality.get_cldr_names_order():
-            if name in mapping:
-                names.append(name)
+        mapping = self.personality.get_expand_output_target_mapping(
+            self._get_target_mapping()
+        )
+        names = [
+            name for name in self.personality.get_cldr_names_order() if name in mapping
+        ]
         return self._get_units(names)
 
     def hasplural(self, key=None):
@@ -639,7 +674,7 @@ class proppluralunit(base.TranslationUnit):
     def settarget(self, text):
         mapping = None
         if isinstance(text, multistring):
-            strings = text.strings
+            strings = [str(x) for x in text.strings]
         elif isinstance(text, list):
             strings = text
         elif isinstance(text, dict):
@@ -652,7 +687,11 @@ class proppluralunit(base.TranslationUnit):
         strings = self._get_strings(strings, mapping)
         units = self._get_units(mapping)
         if len(strings) != len(units):
-            raise Exception(f'Not same plural counts between "{strings}" and "{units}"')
+            raise ValueError(
+                f'Not same plural counts between "{strings}" and "{units}"'
+            )
+        if "other" not in mapping and "other" in self.units:
+            self.units["other"].target = strings[-1]
 
         for a, b in zip(strings, units):
             b.target = a
@@ -687,7 +726,9 @@ class proppluralunit(base.TranslationUnit):
         strings = self._get_strings(strings, mapping)
         units = self._get_units(mapping)
         if len(strings) != len(units):
-            raise Exception(f'Not same plural counts between "{strings}" and "{units}"')
+            raise ValueError(
+                f'Not same plural counts between "{strings}" and "{units}"'
+            )
 
         for a, b in zip(strings, units):
             b.source = a
@@ -735,7 +776,8 @@ class proppluralunit(base.TranslationUnit):
         self.units[variant] = unit
 
     def isblank(self):
-        """returns whether this is a blank element, containing only
+        """
+        Returns whether this is a blank element, containing only
         comments.
         """
         return not (self.name or self.value)
@@ -758,7 +800,8 @@ class proppluralunit(base.TranslationUnit):
         self._get_source_unit().missing = missing
 
     def __str__(self):
-        """Convert to a string. Double check that unicode is handled
+        """
+        Convert to a string. Double check that unicode is handled
         somehow here.
         """
         return self.getoutput()
@@ -779,10 +822,17 @@ class DialectJoomla(Dialect):
     default_encoding = "utf-8"
     delimiters = ["="]
     out_delimiter_wrappers = ""
+    encode_trans = str.maketrans(
+        {
+            "\n": r"\n",
+            "\t": r"\t",
+            '"': '"_QQ_"',
+        }
+    )
 
     @staticmethod
     def value_strip(value):
-        """Strip unneeded characters from the value"""
+        """Strip unneeded characters from the value."""
         return value.strip()
 
     @classmethod
@@ -792,18 +842,17 @@ class DialectJoomla(Dialect):
             string = string[1:-1]
         return string.replace('"_QQ_"', '"')
 
-    @staticmethod
-    def encode(string, encoding=None):
-        """Encode the string"""
+    @classmethod
+    def encode(cls, string, encoding=None):  # noqa: ARG003
+        """Encode the string."""
         if not string:
             return string
-        return '"%s"' % string.replace("\n", r"\n").replace("\t", r"\t").replace(
-            '"', '"_QQ_"'
-        )
+        return f'"{string.translate(cls.encode_trans)}"'
 
 
 class propunit(base.TranslationUnit):
-    """An element of a properties file i.e. a name and value, and any comments
+    """
+    An element of a properties file i.e. a name and value, and any comments
     associated.
     """
 
@@ -850,7 +899,7 @@ class propunit(base.TranslationUnit):
 
     @staticmethod
     def represents_missing(line):
-        """The line represents a missing translation"""
+        """The line represents a missing translation."""
         return False
 
     @property
@@ -864,7 +913,7 @@ class propunit(base.TranslationUnit):
 
     @property
     def target(self):
-        return re.sub("\\\\ ", " ", self.personality.decode(self.translation))
+        return re.sub(r"\\ ", " ", self.personality.decode(self.translation))
 
     @target.setter
     def target(self, target):
@@ -883,12 +932,12 @@ class propunit(base.TranslationUnit):
         return self.getoutput()
 
     def getoutput(self):
-        """Convert the element back into formatted lines for a .properties file"""
-        notes = self.getnotes()
-        if self.isblank():
-            return notes + "\n"
+        """Convert the element back into formatted lines for a .properties file."""
+        notes = "\n".join(self.comments)
         if notes:
-            notes = notes + "\n"
+            notes = f"{notes}\n"
+        if self.isblank():
+            return notes or "\n"
         # encode key, if needed
         key = self.name
         kwc = self.personality.key_wrap_char
@@ -913,21 +962,44 @@ class propunit(base.TranslationUnit):
         return [self.name]
 
     def addnote(self, text, origin=None, position="append"):
-        if origin in ["programmer", "developer", "source code", None]:
+        if origin in {"programmer", "developer", "source code", None}:
+            if get_comment_one_line(text) is None and get_comment_start(text) is None:
+                text = f"/* {text} */" if "\n" in text else f"// {text}"
             self.comments.append(text)
         else:
             super().addnote(text, origin=origin, position=position)
 
     def getnotes(self, origin=None):
-        if origin in ["programmer", "developer", "source code", None]:
-            return "\n".join(self.comments)
+        if origin in {"programmer", "developer", "source code", None}:
+            output = []
+            inmultilinecomment = False
+            for line in self.comments:
+                if (
+                    not inmultilinecomment
+                    and (parsed := get_comment_one_line(line)) is not None
+                ):
+                    output.append(parsed)
+                elif (
+                    not inmultilinecomment
+                    and (parsed := get_comment_start(line)) is not None
+                ):
+                    output.append(parsed)
+                    inmultilinecomment = True
+                elif (
+                    inmultilinecomment and (parsed := get_comment_end(line)) is not None
+                ):
+                    output.append(parsed)
+                    inmultilinecomment = False
+                else:
+                    output.append(line)
+            return "\n".join(output)
         return super().getnotes(origin)
 
     def removenotes(self, origin=None):
         self.comments = []
 
     def isblank(self):
-        """returns whether this is a blank element, containing only comments."""
+        """Returns whether this is a blank element, containing only comments."""
         return not (self.name or self.value)
 
     def istranslatable(self):
@@ -944,7 +1016,7 @@ class xwikiunit(propunit):
     """
     Represents an XWiki translation unit. The difference with a propunit is twofold:
             1. the dialect used is xwiki for simple quote escape handling
-            2. missing translations are output with a dedicated "### Missing: " prefix
+            2. missing translations are output with a dedicated "### Missing: " prefix.
     """
 
     def __init__(self, source="", personality="xwiki"):
@@ -963,17 +1035,17 @@ class xwikiunit(propunit):
 
     @classmethod
     def represents_missing(cls, line):
-        """Return true if the line represents a missing translation"""
+        """Return true if the line represents a missing translation."""
         return line.startswith(cls.get_missing_part())
 
 
 class propfile(base.TranslationStore):
-    """this class represents a .properties file, made up of propunits"""
+    """this class represents a .properties file, made up of propunits."""
 
     UnitClass = propunit
 
     def __init__(self, inputfile=None, personality="java", encoding=None):
-        """construct a propfile, optionally reading in from inputfile"""
+        """Construct a propfile, optionally reading in from inputfile."""
         super().__init__()
         self.personality = get_dialect(personality)
         self.encoding = encoding or self.personality.default_encoding
@@ -1004,7 +1076,7 @@ class propfile(base.TranslationStore):
 
         for line in propsrc.split("\n"):
             # handle multiline value if we're in one
-            line = quote.rstripeol(line)
+            line = rstripeol(line)
             if inmultilinevalue:
                 newunit.value += line.lstrip()
                 # see if there's more
@@ -1023,16 +1095,18 @@ class propfile(base.TranslationStore):
             # FIXME handle // inline comments
             elif (
                 inmultilinecomment
-                or is_comment_one_line(line)
-                or is_comment_start(line)
-                or is_comment_end(line)
+                or (one_line_comment := get_comment_one_line(line)) is not None
+                or (comment_start := get_comment_start(line)) is not None
             ) and not self.UnitClass.represents_missing(line):
                 # add a comment
                 if line not in self.personality.drop_comments:
                     newunit.comments.append(line)
-                if is_comment_start(line):
+
+                if one_line_comment is not None:
+                    pass
+                elif not inmultilinecomment and comment_start is not None:
                     inmultilinecomment = True
-                elif is_comment_end(line):
+                elif inmultilinecomment and get_comment_end(line) is not None:
                     inmultilinecomment = False
             elif not line.strip():
                 # this is a blank line...
@@ -1079,11 +1153,7 @@ class propfile(base.TranslationStore):
                         self.addunit(newunit)
                         newunit = self.UnitClass("", self.personality.name)
         # see if there is a leftover one...
-        if (
-            inmultilinevalue
-            or len(newunit.comments) > 0
-            and not (len(newunit.comments) == 1 and not (newunit.comments[0]))
-        ):
+        if inmultilinevalue or any(newunit.comments):
             self.addunit(newunit)
 
         if self.personality.has_plurals:
@@ -1199,7 +1269,7 @@ class joomlafile(propfile):
 class XWikiPageProperties(xwikifile):
     """
     Represents an XWiki Page containing translation properties as described in
-    https://dev.xwiki.org/xwiki/bin/view/Community/XWiki%20Translations%20Formats/#HXWikiPageProperties
+    https://dev.xwiki.org/xwiki/bin/view/Community/XWiki%20Translations%20Formats/#HXWikiPageProperties.
     """
 
     Name = "XWiki Page Properties"
@@ -1301,6 +1371,8 @@ class XWikiPageProperties(xwikifile):
         # if we are editing the source file we should not modify it.
         if not self.is_source_file():
             self.set_xwiki_xml_attributes(newroot)
+            # We only want a single line break before the closing node.
+            newroot.find("content").tail = "\n"
         self.write_xwiki_xml(newroot, out)
 
 
@@ -1309,7 +1381,7 @@ class XWikiFullPage(XWikiPageProperties):
     Represents a full XWiki Page translation: this file does not contains properties
     but its whole content needs to be translated.
     More information on
-    https://dev.xwiki.org/xwiki/bin/view/Community/XWiki%20Translations%20Formats/#HXWikiFullContentTranslation
+    https://dev.xwiki.org/xwiki/bin/view/Community/XWiki%20Translations%20Formats/#HXWikiFullContentTranslation.
     """
 
     Name = "XWiki Full Page"
@@ -1320,9 +1392,9 @@ class XWikiFullPage(XWikiPageProperties):
             content = "".join(self.root.find("content").itertext()).replace("\n", "\\n")
             title = "".join(self.root.find("title").itertext())
             forparsing = ""
-            if content != "":
+            if content:
                 forparsing += f"content={content}\n"
-            if title != "":
+            if title:
                 forparsing += f"title={title}\n"
             self.extract_language()
             super(XWikiPageProperties, self).parse(forparsing.encode(self.encoding))
